//+------------------------------------------------------------------+
//|                                                AutoDayFibs V1.3  |
//|                                                                  |
//|              Copyright  2005-2008, Jason Robinson (jnrtrading)  |
//|                                 http://www.spreadtrade2win.com   |
//|                                                                  |
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//|                                                                  |
//|Options: AutomaticallyAdjustToToday (true/false);                 |
//|               Determine whether to have the indicator            |
//|               automatically adjust to todays prices.             |
//|         TimeToAdjust (in 24 hour format 0-23);                   |
//|               If AutomaticallyAdjustToToday is set               |
//|               to 'true' then you can determine at                |
//|               what time the fib lines switch to using            |
//|               todays prices instead of yesterdays.               |
//|               Works only for whole hours.                        |
//|         DaysBackForHigh and DaysBackForLow;                      |
//|               If AutomaticallyAdjustToToday is set               |
//|               to 'false' then you can adjust the                 |
//|               amount of days back to take the high               |
//|               and low readings from.                             |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2005-2008, Jason Robinson (jnrtrading)"
#property link      "http://www.spreadtrade2win.com"

#property indicator_chart_window
extern bool   AutomaticallyAdjustToToday = true;
extern int    TimeToAdjust;
extern int    DaysBackForHigh;
extern int    DaysBackForLow;  
extern color  ColourOfLines              = DodgerBlue;
extern bool   alertsOn                   = true;
extern bool   alertsOn50Touch            = true;
extern bool   alertsOn618Touch           = true;
extern bool   alertsOnCurrent            = true;
extern bool   alertsMessage              = true;
extern bool   alertsSound                = false;
extern bool   alertsEmail                = false;
extern bool   alertsNotify               = false;
extern string soundFile                  = "alert2.wav";

//
//
//
//
//

double trend1[];
double trend2[];
double Rates[][6];

double fib50,
       fib618,
       range,
       prevRange,
       high,
       low;
       

bool objectsExist, highFirst;

//---- buffers

       

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   IndicatorBuffers(2);
   SetIndexBuffer(0,trend1);
   SetIndexBuffer(1,trend2);

prevRange = 0;
objectsExist = false;
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//---- 
   
   ObjectDelete("fib50");
   ObjectDelete("fib50_label");
   ObjectDelete("fib618");
   ObjectDelete("fib618_label");
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{ 
   int i,counted_bars=IndicatorCounted();
      if(counted_bars<0) return(-1);
      if(counted_bars>0) counted_bars--;
         int limit = MathMin(Bars-counted_bars,Bars-1);
         ArrayCopyRates(Rates, Symbol(), PERIOD_D1);   
   
   if (AutomaticallyAdjustToToday == true) 
   {
      if (Hour() >= 0 && Hour() < TimeToAdjust) 
      {
         DaysBackForHigh = 1;
         DaysBackForLow  = 1;
      }
      else if (Hour() >= DaysBackForLow && Hour() <= 23) 
      {
         DaysBackForHigh = 0;
         DaysBackForLow  = 0;
      }
   }
   high  = Rates[DaysBackForHigh][3];
   low   = Rates[DaysBackForLow][2];
   range = high - low;
   
   for(i=limit; i>=0; i--)
   {
      if(High[i] == high) {
         highFirst = true;
         break;
      }
      else if(Low[i] == low) {
         highFirst = false;
         break;
      }
   //Print(highFirst);
   
   // Delete Objects if necessary
   if (prevRange != range) 
   {
      
      ObjectDelete("fib50");
      ObjectDelete("fib50_label");
      ObjectDelete("fib618");
      ObjectDelete("fib618_label");
  
      objectsExist = false;
      prevRange = range;
      //Print("Objects do not exist");
   }
   
   if (highFirst == false) 
   {
      fib50  = (high + low) / 2;
      fib618 = (range * 0.618) + low;
  
   }
   else if (highFirst == true) 
   {
      
      fib50  = (high + low) / 2;
      fib618 = high - (range * 0.618);   
   } 
      trend1[i] = trend1[i+1];
      trend2[i] = trend2[i+1];
      if (Close[i]>=fib50)  trend1[i] = 1;
      if (Close[i]<=fib50)  trend1[i] =-1;
      if (Close[i]>=fib618) trend2[i] = 1;
      if (Close[i]<=fib618) trend2[i] =-1;  
   }
   if (objectsExist == false) 
   {
      ObjectCreate("fib50", OBJ_HLINE, 0, Time[0], fib50);
         ObjectSet("fib50", OBJPROP_STYLE, STYLE_DASHDOTDOT);
         ObjectSet("fib50", OBJPROP_COLOR, ColourOfLines);
      ObjectCreate("fib50_label", OBJ_TEXT, 0, Time[0], fib50);
      ObjectSetText("fib50_label","                             50.0", 8, "Times", Black);
   
      ObjectCreate("fib618", OBJ_HLINE, 0, Time[0], fib618);
         ObjectSet("fib618", OBJPROP_STYLE, STYLE_DASHDOTDOT);
         ObjectSet("fib618", OBJPROP_COLOR, ColourOfLines);
      ObjectCreate("fib618_label", OBJ_TEXT, 0, Time[0], fib618);
      ObjectSetText("fib618_label","                             61.8", 8, "Times", Black);
      
   }
   
   //
   //
   //
   //
   //
   
   if (alertsOn)
   {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1;
      
      //
      //
      //
      //
      //
      
      static datetime time1 = 0;
      static string   mess1 = "";
         if (alertsOn50Touch && trend1[whichBar] != trend1[whichBar+1])
         {
            if (trend1[whichBar] ==  1) doAlert(time1,mess1,whichBar," touching 50.0 Fib ");
            if (trend1[whichBar] == -1) doAlert(time1,mess1,whichBar," touching 50.0 Fib ");
         }            
      static datetime time2 = 0;
      static string   mess2 = "";
         if (alertsOn618Touch && trend2[whichBar] != trend2[whichBar+1])
         {
            if (trend2[whichBar] ==  1) doAlert(time2,mess2,whichBar," touching 61.8 Fib ");
            if (trend2[whichBar] == -1) doAlert(time2,mess2,whichBar," touching 61.8 Fib ");
         }
   }
return(0);
}

//
//
//
//
//

void doAlert(datetime& previousTime, string& previousAlert, int forBar, string doWhat)
{
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[forBar]) {
          previousAlert  = doWhat;
          previousTime   = Time[forBar];

          //
          //
          //
          //
          //

          message =  Symbol()+" at "+TimeToStr(TimeLocal(),TIME_SECONDS)+" AutoDayFibs "+doWhat;
             if (alertsMessage) Alert(message);
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," AutoDayFibs "),message);
             if (alertsNotify)  SendNotification(StringConcatenate(Symbol(), Period() ," AutoDayFibs " +" "+message));
             if (alertsSound)   PlaySound(soundFile);
      }
}